# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/report_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/report_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.loadtesting.api.v1.report import kpi_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_kpi__pb2
from yandex.cloud.loadtesting.api.v1.report import kpi_value_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_kpi__value__pb2
from yandex.cloud.loadtesting.api.v1.report.table import report_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_table_dot_report__pb2
from yandex.cloud.loadtesting.api.v1.report import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_status__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/api/v1/report_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x30yandex/cloud/loadtesting/api/v1/report/kpi.proto\x1a\x36yandex/cloud/loadtesting/api/v1/report/kpi_value.proto\x1a\x39yandex/cloud/loadtesting/api/v1/report/table/report.proto\x1a\x33yandex/cloud/loadtesting/api/v1/report/status.proto\x1a\x1dyandex/cloud/validation.proto\".\n\x15GetTableReportRequest\x12\x15\n\x07test_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xd6\x02\n\x16GetTableReportResponse\x12>\n\x06status\x18\x01 \x01(\x0e\x32..yandex.cloud.loadtesting.api.v1.report.Status\x12\x45\n\x07overall\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.table.Report\x12Q\n\x05\x63\x61ses\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.loadtesting.api.v1.GetTableReportResponse.CasesEntry\x1a\x62\n\nCasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.table.Report:\x02\x38\x01\"\xc5\x01\n\x1f\x43\x61lculateReportKpiValuesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=54\x12#\n\x0btest_filter\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12\x1c\n\ttest_case\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12>\n\x03kpi\x18\x04 \x01(\x0b\x32+.yandex.cloud.loadtesting.api.v1.report.KpiB\x04\xe8\xc7\x31\x01\"w\n CalculateReportKpiValuesResponse\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12@\n\x06values\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.loadtesting.api.v1.report.KpiValue2\x99\x03\n\rReportService\x12\xb0\x01\n\x08GetTable\x12\x36.yandex.cloud.loadtesting.api.v1.GetTableReportRequest\x1a\x37.yandex.cloud.loadtesting.api.v1.GetTableReportResponse\"3\x82\xd3\xe4\x93\x02-\x12+/loadtesting/api/v1/reports/{test_id}/table\x12\xd4\x01\n\x12\x43\x61lculateKpiValues\x12@.yandex.cloud.loadtesting.api.v1.CalculateReportKpiValuesRequest\x1a\x41.yandex.cloud.loadtesting.api.v1.CalculateReportKpiValuesResponse\"9\x82\xd3\xe4\x93\x02\x33\"./loadtesting/api/v1/reports/calculateKpiValues:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _globals['_GETTABLEREPORTREQUEST'].fields_by_name['test_id']._loaded_options = None
  _globals['_GETTABLEREPORTREQUEST'].fields_by_name['test_id']._serialized_options = b'\350\3071\001'
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._loaded_options = None
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._serialized_options = b'8\001'
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=54'
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['test_filter']._loaded_options = None
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['test_filter']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['test_case']._loaded_options = None
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['test_case']._serialized_options = b'\212\3101\005<=100'
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['kpi']._loaded_options = None
  _globals['_CALCULATEREPORTKPIVALUESREQUEST'].fields_by_name['kpi']._serialized_options = b'\350\3071\001'
  _globals['_REPORTSERVICE'].methods_by_name['GetTable']._loaded_options = None
  _globals['_REPORTSERVICE'].methods_by_name['GetTable']._serialized_options = b'\202\323\344\223\002-\022+/loadtesting/api/v1/reports/{test_id}/table'
  _globals['_REPORTSERVICE'].methods_by_name['CalculateKpiValues']._loaded_options = None
  _globals['_REPORTSERVICE'].methods_by_name['CalculateKpiValues']._serialized_options = b'\202\323\344\223\0023\"./loadtesting/api/v1/reports/calculateKpiValues:\001*'
  _globals['_GETTABLEREPORTREQUEST']._serialized_start=368
  _globals['_GETTABLEREPORTREQUEST']._serialized_end=414
  _globals['_GETTABLEREPORTRESPONSE']._serialized_start=417
  _globals['_GETTABLEREPORTRESPONSE']._serialized_end=759
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._serialized_start=661
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._serialized_end=759
  _globals['_CALCULATEREPORTKPIVALUESREQUEST']._serialized_start=762
  _globals['_CALCULATEREPORTKPIVALUESREQUEST']._serialized_end=959
  _globals['_CALCULATEREPORTKPIVALUESRESPONSE']._serialized_start=961
  _globals['_CALCULATEREPORTKPIVALUESRESPONSE']._serialized_end=1080
  _globals['_REPORTSERVICE']._serialized_start=1083
  _globals['_REPORTSERVICE']._serialized_end=1492
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Registry(google.protobuf.message.Message):
    """A Registry resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Registry._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Registry._Status.ValueType  # 0
        CREATING: Registry._Status.ValueType  # 1
        """Registry is being created."""
        ACTIVE: Registry._Status.ValueType  # 2
        """Registry is ready to use."""
        DELETING: Registry._Status.ValueType  # 3
        """Registry is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Registry.Status.ValueType  # 0
    CREATING: Registry.Status.ValueType  # 1
    """Registry is being created."""
    ACTIVE: Registry.Status.ValueType  # 2
    """Registry is ready to use."""
    DELETING: Registry.Status.ValueType  # 3
    """Registry is being deleted."""

    class _Kind:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _KindEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Registry._Kind.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        KIND_UNSPECIFIED: Registry._Kind.ValueType  # 0
        MAVEN: Registry._Kind.ValueType  # 1
        """Registry kind is maven."""
        NPM: Registry._Kind.ValueType  # 2
        """Registry kind is npm."""
        DOCKER: Registry._Kind.ValueType  # 3
        """Registry kind is docker."""
        NUGET: Registry._Kind.ValueType  # 4
        """Registry kind is nuget."""

    class Kind(_Kind, metaclass=_KindEnumTypeWrapper): ...
    KIND_UNSPECIFIED: Registry.Kind.ValueType  # 0
    MAVEN: Registry.Kind.ValueType  # 1
    """Registry kind is maven."""
    NPM: Registry.Kind.ValueType  # 2
    """Registry kind is npm."""
    DOCKER: Registry.Kind.ValueType  # 3
    """Registry kind is docker."""
    NUGET: Registry.Kind.ValueType  # 4
    """Registry kind is nuget."""

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Registry._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Registry._Type.ValueType  # 0
        LOCAL: Registry._Type.ValueType  # 1
        """Registry type is local."""
        REMOTE: Registry._Type.ValueType  # 2
        VIRTUAL: Registry._Type.ValueType  # 3

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Registry.Type.ValueType  # 0
    LOCAL: Registry.Type.ValueType  # 1
    """Registry type is local."""
    REMOTE: Registry.Type.ValueType  # 2
    VIRTUAL: Registry.Type.ValueType  # 3

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the registry."""
    folder_id: builtins.str
    """ID of the folder that the registry belongs to."""
    name: builtins.str
    """Name of the registry."""
    kind: global___Registry.Kind.ValueType
    """Kind of the registry."""
    type: global___Registry.Type.ValueType
    """Type of the registry."""
    status: global___Registry.Status.ValueType
    """Output only. Status of the registry."""
    description: builtins.str
    """Description of the registry."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource properties as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Modification timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        kind: global___Registry.Kind.ValueType = ...,
        type: global___Registry.Type.ValueType = ...,
        status: global___Registry.Status.ValueType = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "kind", b"kind", "labels", b"labels", "modified_at", b"modified_at", "name", b"name", "properties", b"properties", "status", b"status", "type", b"type"]) -> None: ...

global___Registry = Registry



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/agent/v1/monitoring_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/agent/v1/monitoring_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/loadtesting/agent/v1/monitoring_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"\xca\x01\n\x10\x41\x64\x64MetricRequest\x12%\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x06\x63hunks\x18\x04 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.MetricChunkB\x06\x82\xc8\x31\x02>0\x12#\n\x11\x61gent_instance_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"\x8f\x01\n\x0bMetricChunk\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32).yandex.cloud.loadtesting.agent.v1.MetricB\x06\x82\xc8\x31\x02>0\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x1b\n\rinstance_host\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x06Metric\x12\x19\n\x0bmetric_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bmetric_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x0cmetric_value\x18\x03 \x01(\x01\":\n\x11\x41\x64\x64MetricResponse\x12\x17\n\x0fmetric_trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xc8\x01\n\x11MonitoringService\x12\xb2\x01\n\tAddMetric\x12\x33.yandex.cloud.loadtesting.agent.v1.AddMetricRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.AddMetricResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/monitorings/reportMetrics:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _globals['_ADDMETRICREQUEST'].fields_by_name['compute_instance_id']._loaded_options = None
  _globals['_ADDMETRICREQUEST'].fields_by_name['compute_instance_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ADDMETRICREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_ADDMETRICREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDMETRICREQUEST'].fields_by_name['chunks']._loaded_options = None
  _globals['_ADDMETRICREQUEST'].fields_by_name['chunks']._serialized_options = b'\202\3101\002>0'
  _globals['_ADDMETRICREQUEST'].fields_by_name['agent_instance_id']._loaded_options = None
  _globals['_ADDMETRICREQUEST'].fields_by_name['agent_instance_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_METRICCHUNK'].fields_by_name['data']._loaded_options = None
  _globals['_METRICCHUNK'].fields_by_name['data']._serialized_options = b'\202\3101\002>0'
  _globals['_METRICCHUNK'].fields_by_name['instance_host']._loaded_options = None
  _globals['_METRICCHUNK'].fields_by_name['instance_host']._serialized_options = b'\350\3071\001'
  _globals['_METRIC'].fields_by_name['metric_type']._loaded_options = None
  _globals['_METRIC'].fields_by_name['metric_type']._serialized_options = b'\350\3071\001'
  _globals['_METRIC'].fields_by_name['metric_name']._loaded_options = None
  _globals['_METRIC'].fields_by_name['metric_name']._serialized_options = b'\350\3071\001'
  _globals['_MONITORINGSERVICE'].methods_by_name['AddMetric']._loaded_options = None
  _globals['_MONITORINGSERVICE'].methods_by_name['AddMetric']._serialized_options = b'\202\323\344\223\0024\"//loadtesting/agent/v1/monitorings/reportMetrics:\001*'
  _globals['_ADDMETRICREQUEST']._serialized_start=159
  _globals['_ADDMETRICREQUEST']._serialized_end=361
  _globals['_METRICCHUNK']._serialized_start=364
  _globals['_METRICCHUNK']._serialized_end=507
  _globals['_METRIC']._serialized_start=509
  _globals['_METRIC']._serialized_end=593
  _globals['_ADDMETRICRESPONSE']._serialized_start=595
  _globals['_ADDMETRICRESPONSE']._serialized_end=653
  _globals['_MONITORINGSERVICE']._serialized_start=656
  _globals['_MONITORINGSERVICE']._serialized_end=856
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.apigateway.v1.apigateway_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetApiGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway to return.

    To get a API gateway ID make a [ApiGatewayService.List] request.
    """
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id"]) -> None: ...

global___GetApiGatewayRequest = GetApiGatewayRequest

@typing.final
class ListApiGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list API gateways in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListApiGatewayResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListApiGatewayResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters functions listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [ApiGateway.name](index) field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z]([-a-z0-9]{0,61}[a-z0-9])?`.
    Example of a filter: `name=my-apigw`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApiGatewayRequest = ListApiGatewayRequest

@typing.final
class ListApiGatewayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListApiGatewayRequest.page_size], use `nextPageToken` as the value
    for the [ListApiGatewayRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def api_gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway]:
        """List of API gateways in the specified folder."""

    def __init__(
        self,
        *,
        api_gateways: collections.abc.Iterable[yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateways", b"api_gateways", "next_page_token", b"next_page_token"]) -> None: ...

global___ListApiGatewayResponse = ListApiGatewayResponse

@typing.final
class CreateApiGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    OPENAPI_SPEC_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    CANARY_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an API gateway in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the API gateway.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the API gateway."""
    openapi_spec: builtins.str
    """The text of specification, JSON or YAML."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def connectivity(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Connectivity:
        """Gateway connectivity. If specified the gateway will be attached to specified network/subnet(s)."""

    @property
    def log_options(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.LogOptions:
        """Options for logging from the API gateway."""

    @property
    def variables(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput]:
        """Values of variables defined in the specification."""

    @property
    def canary(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Canary:
        """Canary release of the gateway."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for gateway call execution"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        openapi_spec: builtins.str = ...,
        connectivity: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Connectivity | None = ...,
        log_options: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.LogOptions | None = ...,
        variables: collections.abc.Mapping[builtins.str, yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput] | None = ...,
        canary: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Canary | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["canary", b"canary", "connectivity", b"connectivity", "execution_timeout", b"execution_timeout", "log_options", b"log_options", "openapi_spec", b"openapi_spec", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["canary", b"canary", "connectivity", b"connectivity", "description", b"description", "execution_timeout", b"execution_timeout", "folder_id", b"folder_id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "openapi_spec", b"openapi_spec", "spec", b"spec", "variables", b"variables"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["spec", b"spec"]) -> typing.Literal["openapi_spec"] | None: ...

global___CreateApiGatewayRequest = CreateApiGatewayRequest

@typing.final
class UpdateApiGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    OPENAPI_SPEC_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    CANARY_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway to update.

    To get a API gateway ID make a [ApiGatewayService.List] request.
    """
    name: builtins.str
    """New name for the API gateway.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description for the API gateway."""
    openapi_spec: builtins.str
    """The text of specification, JSON or YAML."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the API gateway should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """API gateway labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label, request the current set of labels with a [yandex.cloud.serverless.apigateway.v1.ApiGatewayService.Get] request.
        """

    @property
    def connectivity(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Connectivity:
        """Gateway connectivity. If specified the gateway will be attached to specified network/subnet(s)."""

    @property
    def log_options(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.LogOptions:
        """Options for logging from the API gateway."""

    @property
    def variables(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput]:
        """Values of variables defined in the specification."""

    @property
    def canary(self) -> yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Canary:
        """Canary release of the gateway."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for gateway call execution"""

    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        openapi_spec: builtins.str = ...,
        connectivity: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Connectivity | None = ...,
        log_options: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.LogOptions | None = ...,
        variables: collections.abc.Mapping[builtins.str, yandex.cloud.serverless.apigateway.v1.apigateway_pb2.VariableInput] | None = ...,
        canary: yandex.cloud.serverless.apigateway.v1.apigateway_pb2.Canary | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["canary", b"canary", "connectivity", b"connectivity", "execution_timeout", b"execution_timeout", "log_options", b"log_options", "openapi_spec", b"openapi_spec", "spec", b"spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "canary", b"canary", "connectivity", b"connectivity", "description", b"description", "execution_timeout", b"execution_timeout", "labels", b"labels", "log_options", b"log_options", "name", b"name", "openapi_spec", b"openapi_spec", "spec", b"spec", "update_mask", b"update_mask", "variables", b"variables"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["spec", b"spec"]) -> typing.Literal["openapi_spec"] | None: ...

global___UpdateApiGatewayRequest = UpdateApiGatewayRequest

@typing.final
class DeleteApiGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway to update.

    To get a API gateway ID make a [ApiGatewayService.List] request.
    """
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id"]) -> None: ...

global___DeleteApiGatewayRequest = DeleteApiGatewayRequest

@typing.final
class AddDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway that the domain is attached to."""
    domain_name: builtins.str
    """Name of the attaching domain."""
    certificate_id: builtins.str
    """ID of certificate for the attaching domain."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        domain_name: builtins.str = ...,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "certificate_id", b"certificate_id", "domain_name", b"domain_name"]) -> None: ...

global___AddDomainRequest = AddDomainRequest

@typing.final
class RemoveDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    DOMAIN_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway from which the domain is being detached."""
    domain_id: builtins.str
    """ID of the detaching domain."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        domain_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "domain_id", b"domain_id"]) -> None: ...

global___RemoveDomainRequest = RemoveDomainRequest

@typing.final
class CreateApiGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway that is being created."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id"]) -> None: ...

global___CreateApiGatewayMetadata = CreateApiGatewayMetadata

@typing.final
class UpdateApiGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway that is being updated."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id"]) -> None: ...

global___UpdateApiGatewayMetadata = UpdateApiGatewayMetadata

@typing.final
class DeleteApiGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway that is being deleted."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id"]) -> None: ...

global___DeleteApiGatewayMetadata = DeleteApiGatewayMetadata

@typing.final
class AddDomainMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    DOMAIN_ID_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway that the domain is attached to."""
    domain_id: builtins.str
    """ID of the attached domain."""
    domain_name: builtins.str
    """Name of the attaching domain."""
    certificate_id: builtins.str
    """ID of the certificate for provided domain."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        domain_id: builtins.str = ...,
        domain_name: builtins.str = ...,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "certificate_id", b"certificate_id", "domain_id", b"domain_id", "domain_name", b"domain_name"]) -> None: ...

global___AddDomainMetadata = AddDomainMetadata

@typing.final
class RemoveDomainMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    DOMAIN_ID_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway from which the domain is being detached."""
    domain_id: builtins.str
    """ID of the detaching domain."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        domain_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "domain_id", b"domain_id"]) -> None: ...

global___RemoveDomainMetadata = RemoveDomainMetadata

@typing.final
class ListOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.done], [operation.Operation.created_by] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOperationsRequest = ListOperationsRequest

@typing.final
class ListOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListOperationsRequest.page_size], use `nextPageToken` as the value
    for the [ListOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified API gateway."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListOperationsResponse = ListOperationsResponse

@typing.final
class GetOpenapiSpecRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Format:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetOpenapiSpecRequest._Format.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORMAT_UNSPECIFIED: GetOpenapiSpecRequest._Format.ValueType  # 0
        JSON: GetOpenapiSpecRequest._Format.ValueType  # 1
        YAML: GetOpenapiSpecRequest._Format.ValueType  # 2

    class Format(_Format, metaclass=_FormatEnumTypeWrapper): ...
    FORMAT_UNSPECIFIED: GetOpenapiSpecRequest.Format.ValueType  # 0
    JSON: GetOpenapiSpecRequest.Format.ValueType  # 1
    YAML: GetOpenapiSpecRequest.Format.ValueType  # 2

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway to get specification from."""
    format: global___GetOpenapiSpecRequest.Format.ValueType
    """Format of returned specification. Default is the original format used in [CreateApiGatewayRequest]."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        format: global___GetOpenapiSpecRequest.Format.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "format", b"format"]) -> None: ...

global___GetOpenapiSpecRequest = GetOpenapiSpecRequest

@typing.final
class GetOpenapiSpecResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GATEWAY_ID_FIELD_NUMBER: builtins.int
    OPENAPI_SPEC_FIELD_NUMBER: builtins.int
    api_gateway_id: builtins.str
    """ID of the API gateway."""
    openapi_spec: builtins.str
    """The text of specification, JSON or YAML."""
    def __init__(
        self,
        *,
        api_gateway_id: builtins.str = ...,
        openapi_spec: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_gateway_id", b"api_gateway_id", "openapi_spec", b"openapi_spec"]) -> None: ...

global___GetOpenapiSpecResponse = GetOpenapiSpecResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.airflow.v1.common_pb2
import yandex.cloud.airflow.v1.maintenance_pb2
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """Apache Airflow cluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        STOPPING: Cluster._Status.ValueType  # 4
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 5
        """Cluster is stopped."""
        STARTING: Cluster._Status.ValueType  # 6
        """Cluster is starting."""
        UPDATING: Cluster._Status.ValueType  # 7
        """Cluster is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    STOPPING: Cluster.Status.ValueType  # 4
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 5
    """Cluster is stopped."""
    STARTING: Cluster.Status.ValueType  # 6
    """Cluster is starting."""
    UPDATING: Cluster.Status.ValueType  # 7
    """Cluster is being updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    CODE_SYNC_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    WEBSERVER_URL_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique ID of the Apache Airflow cluster.
    This ID is assigned by Cloud during cluster creation.
    """
    folder_id: builtins.str
    """ID of the folder that the Apache Airflow cluster belongs to."""
    name: builtins.str
    """Name of the Apache Airflow cluster.
    The name is unique within the folder. 1-64 characters long.
    """
    description: builtins.str
    """Description of the Apache Airflow cluster. 0-256 characters long."""
    health: yandex.cloud.airflow.v1.common_pb2.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Cluster status."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster."""
    webserver_url: builtins.str
    """Address of Apache Airflow web UI."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources.
    For more information, see [documentation](/docs/managed-airflow/concepts/impersonation).
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the Apache Airflow cluster was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Monitoring systems relevant to the Apache Airflow cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of Apache Airflow components."""

    @property
    def network(self) -> global___NetworkConfig:
        """Network related configuration options."""

    @property
    def code_sync(self) -> global___CodeSyncConfig:
        """Parameters of the location and access to the code that will be executed in the cluster."""

    @property
    def logging(self) -> global___LoggingConfig:
        """Cloud Logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    @property
    def planned_operation(self) -> yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest maintenance_window."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        health: yandex.cloud.airflow.v1.common_pb2.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        network: global___NetworkConfig | None = ...,
        code_sync: global___CodeSyncConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        webserver_url: builtins.str = ...,
        service_account_id: builtins.str = ...,
        logging: global___LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["code_sync", b"code_sync", "config", b"config", "created_at", b"created_at", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["code_sync", b"code_sync", "config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network", b"network", "planned_operation", b"planned_operation", "service_account_id", b"service_account_id", "status", b"status", "webserver_url", b"webserver_url"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_ID_FIELD_NUMBER: builtins.int
    AIRFLOW_FIELD_NUMBER: builtins.int
    WEBSERVER_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    TRIGGERER_FIELD_NUMBER: builtins.int
    WORKER_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    LOCKBOX_FIELD_NUMBER: builtins.int
    AIRFLOW_VERSION_FIELD_NUMBER: builtins.int
    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    version_id: builtins.str
    """Version of Apache Airflow that runs on the cluster.
    Use `airlow_version` instead.
    """
    airflow_version: builtins.str
    """Apache Airflow version. Format: "Major.Minor" """
    python_version: builtins.str
    """Python version. Format: "Major.Minor" """
    @property
    def airflow(self) -> global___AirflowConfig:
        """Configuration of the Apache Airflow application itself."""

    @property
    def webserver(self) -> global___WebserverConfig:
        """Configuration of webserver instances."""

    @property
    def scheduler(self) -> global___SchedulerConfig:
        """Configuration of scheduler instances."""

    @property
    def triggerer(self) -> global___TriggererConfig:
        """Configuration of triggerer instances."""

    @property
    def worker(self) -> global___WorkerConfig:
        """Configuration of worker instances."""

    @property
    def dependencies(self) -> global___Dependencies:
        """The list of additional packages installed in the cluster."""

    @property
    def lockbox(self) -> global___LockboxConfig:
        """Configuration of Lockbox Secret Backend."""

    def __init__(
        self,
        *,
        version_id: builtins.str = ...,
        airflow: global___AirflowConfig | None = ...,
        webserver: global___WebserverConfig | None = ...,
        scheduler: global___SchedulerConfig | None = ...,
        triggerer: global___TriggererConfig | None = ...,
        worker: global___WorkerConfig | None = ...,
        dependencies: global___Dependencies | None = ...,
        lockbox: global___LockboxConfig | None = ...,
        airflow_version: builtins.str = ...,
        python_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["airflow", b"airflow", "dependencies", b"dependencies", "lockbox", b"lockbox", "scheduler", b"scheduler", "triggerer", b"triggerer", "webserver", b"webserver", "worker", b"worker"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["airflow", b"airflow", "airflow_version", b"airflow_version", "dependencies", b"dependencies", "lockbox", b"lockbox", "python_version", b"python_version", "scheduler", b"scheduler", "triggerer", b"triggerer", "version_id", b"version_id", "webserver", b"webserver", "worker", b"worker"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class AirflowConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Properties to be passed to Apache Airflow configuration file."""

    def __init__(
        self,
        *,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["config", b"config"]) -> None: ...

global___AirflowConfig = AirflowConfig

@typing.final
class WebserverConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    count: builtins.int
    """The number of webserver instances in the cluster."""
    @property
    def resources(self) -> yandex.cloud.airflow.v1.common_pb2.Resources:
        """Resources allocated to webserver instances."""

    def __init__(
        self,
        *,
        count: builtins.int = ...,
        resources: yandex.cloud.airflow.v1.common_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "resources", b"resources"]) -> None: ...

global___WebserverConfig = WebserverConfig

@typing.final
class SchedulerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    count: builtins.int
    """The number of scheduler instances in the cluster."""
    @property
    def resources(self) -> yandex.cloud.airflow.v1.common_pb2.Resources:
        """Resources allocated to scheduler instances."""

    def __init__(
        self,
        *,
        count: builtins.int = ...,
        resources: yandex.cloud.airflow.v1.common_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "resources", b"resources"]) -> None: ...

global___SchedulerConfig = SchedulerConfig

@typing.final
class TriggererConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    count: builtins.int
    """The number of triggerer instances in the cluster."""
    @property
    def resources(self) -> yandex.cloud.airflow.v1.common_pb2.Resources:
        """Resources allocated to triggerer instances."""

    def __init__(
        self,
        *,
        count: builtins.int = ...,
        resources: yandex.cloud.airflow.v1.common_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "resources", b"resources"]) -> None: ...

global___TriggererConfig = TriggererConfig

@typing.final
class WorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_COUNT_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    min_count: builtins.int
    """The minimum number of worker instances in the cluster."""
    max_count: builtins.int
    """The maximum number of worker instances in the cluster."""
    @property
    def resources(self) -> yandex.cloud.airflow.v1.common_pb2.Resources:
        """Resources allocated to worker instances."""

    def __init__(
        self,
        *,
        min_count: builtins.int = ...,
        max_count: builtins.int = ...,
        resources: yandex.cloud.airflow.v1.common_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_count", b"max_count", "min_count", b"min_count", "resources", b"resources"]) -> None: ...

global___WorkerConfig = WorkerConfig

@typing.final
class Dependencies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIP_PACKAGES_FIELD_NUMBER: builtins.int
    DEB_PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def pip_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Python packages that are installed in the cluster."""

    @property
    def deb_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """System packages that are installed in the cluster."""

    def __init__(
        self,
        *,
        pip_packages: collections.abc.Iterable[builtins.str] | None = ...,
        deb_packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deb_packages", b"deb_packages", "pip_packages", b"pip_packages"]) -> None: ...

global___Dependencies = Dependencies

@typing.final
class NetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of VPC network subnets where instances of the cluster are attached."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkConfig = NetworkConfig

@typing.final
class S3Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The name of the Object Storage bucket that stores DAG files used in the cluster."""
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket"]) -> None: ...

global___S3Config = S3Config

@typing.final
class CodeSyncConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S3_FIELD_NUMBER: builtins.int
    @property
    def s3(self) -> global___S3Config: ...
    def __init__(
        self,
        *,
        s3: global___S3Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["s3", b"s3", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["s3", b"s3", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["s3"] | None: ...

global___CodeSyncConfig = CodeSyncConfig

@typing.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Logs generated by the Airflow components are delivered to Cloud Logging."""
    folder_id: builtins.str
    """Logs should be written to default log group for specified folder."""
    log_group_id: builtins.str
    """Logs should be written to log group resolved by ID."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        folder_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "enabled", b"enabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["folder_id", "log_group_id"] | None: ...

global___LoggingConfig = LoggingConfig

@typing.final
class LockboxConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """The setting allows to enable Lockbox Secret Backend."""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

global___LockboxConfig = LockboxConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SearchQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SearchType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SearchTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchQuery._SearchType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SEARCH_TYPE_UNSPECIFIED: SearchQuery._SearchType.ValueType  # 0
        SEARCH_TYPE_RU: SearchQuery._SearchType.ValueType  # 1
        """Russian search type (default), yandex.ru search domain name will be used."""
        SEARCH_TYPE_TR: SearchQuery._SearchType.ValueType  # 2
        """Turkish search type, yandex.tr search domain name will be used."""
        SEARCH_TYPE_COM: SearchQuery._SearchType.ValueType  # 3
        """International search type, yandex.com search domain name will be used."""
        SEARCH_TYPE_KK: SearchQuery._SearchType.ValueType  # 4
        """Kazakh search type, yandex.kz search domain name will be used."""
        SEARCH_TYPE_BE: SearchQuery._SearchType.ValueType  # 5
        """Belarusian search type, yandex.by search domain name will be used."""

    class SearchType(_SearchType, metaclass=_SearchTypeEnumTypeWrapper): ...
    SEARCH_TYPE_UNSPECIFIED: SearchQuery.SearchType.ValueType  # 0
    SEARCH_TYPE_RU: SearchQuery.SearchType.ValueType  # 1
    """Russian search type (default), yandex.ru search domain name will be used."""
    SEARCH_TYPE_TR: SearchQuery.SearchType.ValueType  # 2
    """Turkish search type, yandex.tr search domain name will be used."""
    SEARCH_TYPE_COM: SearchQuery.SearchType.ValueType  # 3
    """International search type, yandex.com search domain name will be used."""
    SEARCH_TYPE_KK: SearchQuery.SearchType.ValueType  # 4
    """Kazakh search type, yandex.kz search domain name will be used."""
    SEARCH_TYPE_BE: SearchQuery.SearchType.ValueType  # 5
    """Belarusian search type, yandex.by search domain name will be used."""

    class _FamilyMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FamilyModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchQuery._FamilyMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FAMILY_MODE_UNSPECIFIED: SearchQuery._FamilyMode.ValueType  # 0
        FAMILY_MODE_NONE: SearchQuery._FamilyMode.ValueType  # 1
        """Filtering is disabled. Search results include any documents regardless of their contents."""
        FAMILY_MODE_MODERATE: SearchQuery._FamilyMode.ValueType  # 2
        """Moderate filter (default value). Documents of the Adult category are excluded from search results
        unless a query is explicitly made for searching resources of this category.
        """
        FAMILY_MODE_STRICT: SearchQuery._FamilyMode.ValueType  # 3
        """Regardless of a search query, documents of the Adult category
        and those with profanity are excluded from search results.
        """

    class FamilyMode(_FamilyMode, metaclass=_FamilyModeEnumTypeWrapper): ...
    FAMILY_MODE_UNSPECIFIED: SearchQuery.FamilyMode.ValueType  # 0
    FAMILY_MODE_NONE: SearchQuery.FamilyMode.ValueType  # 1
    """Filtering is disabled. Search results include any documents regardless of their contents."""
    FAMILY_MODE_MODERATE: SearchQuery.FamilyMode.ValueType  # 2
    """Moderate filter (default value). Documents of the Adult category are excluded from search results
    unless a query is explicitly made for searching resources of this category.
    """
    FAMILY_MODE_STRICT: SearchQuery.FamilyMode.ValueType  # 3
    """Regardless of a search query, documents of the Adult category
    and those with profanity are excluded from search results.
    """

    class _FixTypoMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FixTypoModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchQuery._FixTypoMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FIX_TYPO_MODE_UNSPECIFIED: SearchQuery._FixTypoMode.ValueType  # 0
        FIX_TYPO_MODE_ON: SearchQuery._FixTypoMode.ValueType  # 1
        """Automatically correct typos (default value)."""
        FIX_TYPO_MODE_OFF: SearchQuery._FixTypoMode.ValueType  # 2
        """Autocorrection is off."""

    class FixTypoMode(_FixTypoMode, metaclass=_FixTypoModeEnumTypeWrapper): ...
    FIX_TYPO_MODE_UNSPECIFIED: SearchQuery.FixTypoMode.ValueType  # 0
    FIX_TYPO_MODE_ON: SearchQuery.FixTypoMode.ValueType  # 1
    """Automatically correct typos (default value)."""
    FIX_TYPO_MODE_OFF: SearchQuery.FixTypoMode.ValueType  # 2
    """Autocorrection is off."""

    SEARCH_TYPE_FIELD_NUMBER: builtins.int
    QUERY_TEXT_FIELD_NUMBER: builtins.int
    FAMILY_MODE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FIX_TYPO_MODE_FIELD_NUMBER: builtins.int
    search_type: global___SearchQuery.SearchType.ValueType
    """Search type that determines the domain name that will be used for the search queries."""
    query_text: builtins.str
    """Search query text"""
    family_mode: global___SearchQuery.FamilyMode.ValueType
    """Rule for filtering search results and determines whether any documents should be excluded."""
    page: builtins.int
    """The number of a requested page with search results"""
    fix_typo_mode: global___SearchQuery.FixTypoMode.ValueType
    """Typos autocorrections mode"""
    def __init__(
        self,
        *,
        search_type: global___SearchQuery.SearchType.ValueType = ...,
        query_text: builtins.str = ...,
        family_mode: global___SearchQuery.FamilyMode.ValueType = ...,
        page: builtins.int = ...,
        fix_typo_mode: global___SearchQuery.FixTypoMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["family_mode", b"family_mode", "fix_typo_mode", b"fix_typo_mode", "page", b"page", "query_text", b"query_text", "search_type", b"search_type"]) -> None: ...

global___SearchQuery = SearchQuery



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/database.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/database.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/mdb/postgresql/v1/database.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xee\x01\n\x08\x44\x61tabase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x12\n\nlc_collate\x18\x04 \x01(\t\x12\x10\n\x08lc_ctype\x18\x05 \x01(\t\x12=\n\nextensions\x18\x06 \x03(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Extension\x12\x13\n\x0btemplate_db\x18\x07 \x01(\t\x12\x37\n\x13\x64\x65letion_protection\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"*\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xec\x02\n\x0c\x44\x61tabaseSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12-\n\x05owner\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12+\n\nlc_collate\x18\x03 \x01(\tB\x17\xf2\xc7\x31\x13|[a-zA-Z_]+.UTF-8|C\x12)\n\x08lc_ctype\x18\x04 \x01(\tB\x17\xf2\xc7\x31\x13|[a-zA-Z_]+.UTF-8|C\x12=\n\nextensions\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Extension\x12/\n\x0btemplate_db\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x37\n\x13\x64\x65letion_protection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.database_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_DATABASESPEC'].fields_by_name['name']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASESPEC'].fields_by_name['owner']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['owner']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASESPEC'].fields_by_name['lc_collate']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['lc_collate']._serialized_options = b'\362\3071\023|[a-zA-Z_]+.UTF-8|C'
  _globals['_DATABASESPEC'].fields_by_name['lc_ctype']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['lc_ctype']._serialized_options = b'\362\3071\023|[a-zA-Z_]+.UTF-8|C'
  _globals['_DATABASESPEC'].fields_by_name['template_db']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['template_db']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASE']._serialized_start=145
  _globals['_DATABASE']._serialized_end=383
  _globals['_EXTENSION']._serialized_start=385
  _globals['_EXTENSION']._serialized_end=427
  _globals['_DATABASESPEC']._serialized_start=430
  _globals['_DATABASESPEC']._serialized_end=794
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/statistics_common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/statistics_common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\x12$yandex.cloud.speechsense.v1.analysis\"\x8f\x01\n\x15\x44\x65scriptiveStatistics\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x0c\n\x04mean\x18\x03 \x01(\x01\x12\x0b\n\x03std\x18\x04 \x01(\x01\x12\x41\n\tquantiles\x18\x05 \x03(\x0b\x32..yandex.cloud.speechsense.v1.analysis.Quantile\"(\n\x08Quantile\x12\r\n\x05level\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01\"^\n\x16\x41udioSegmentBoundaries\x12\x15\n\rstart_time_ms\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x02 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\x03 \x01(\x03\x42\x97\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x15StatisticsCommonProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.statistics_common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\025StatisticsCommonProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_DESCRIPTIVESTATISTICS']._serialized_start=103
  _globals['_DESCRIPTIVESTATISTICS']._serialized_end=246
  _globals['_QUANTILE']._serialized_start=248
  _globals['_QUANTILE']._serialized_end=288
  _globals['_AUDIOSEGMENTBOUNDARIES']._serialized_start=290
  _globals['_AUDIOSEGMENTBOUNDARIES']._serialized_end=384
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/elasticsearch/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/elasticsearch/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.mdb.elasticsearch.v1.config import elasticsearch_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_config_dot_elasticsearch__pb2
from yandex.cloud.mdb.elasticsearch.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/elasticsearch/v1/cluster.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a<yandex/cloud/mdb/elasticsearch/v1/config/elasticsearch.proto\x1a\x33yandex/cloud/mdb/elasticsearch/v1/maintenance.proto\"\xe0\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x46\n\x06labels\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.mdb.elasticsearch.v1.Cluster.LabelsEntry\x12K\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x36.yandex.cloud.mdb.elasticsearch.v1.Cluster.Environment\x12\x41\n\nmonitoring\x18\x08 \x03(\x0b\x32-.yandex.cloud.mdb.elasticsearch.v1.Monitoring\x12@\n\x06\x63onfig\x18\t \x01(\x0b\x32\x30.yandex.cloud.mdb.elasticsearch.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x41\n\x06health\x18\x0b \x01(\x0e\x32\x31.yandex.cloud.mdb.elasticsearch.v1.Cluster.Health\x12\x41\n\x06status\x18\x0c \x01(\x0e\x32\x31.yandex.cloud.mdb.elasticsearch.v1.Cluster.Status\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0f \x01(\x08\x12P\n\x12maintenance_window\x18\x10 \x01(\x0b\x32\x34.yandex.cloud.mdb.elasticsearch.v1.MaintenanceWindow\x12R\n\x11planned_operation\x18\x11 \x01(\x0b\x32\x37.yandex.cloud.mdb.elasticsearch.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"z\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12G\n\relasticsearch\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.elasticsearch.v1.Elasticsearch\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\"\xeb\x03\n\rElasticsearch\x12L\n\tdata_node\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.mdb.elasticsearch.v1.Elasticsearch.DataNode\x12P\n\x0bmaster_node\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.elasticsearch.v1.Elasticsearch.MasterNode\x12\x0f\n\x07plugins\x18\x03 \x03(\t\x1a\xd9\x01\n\x08\x44\x61taNode\x12\x81\x01\n\x1a\x65lasticsearch_config_set_7\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.elasticsearch.v1.config.ElasticsearchConfigSet7H\x00R\x18\x65lasticsearchConfigSet_7\x12?\n\tresources\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.ResourcesB\x08\n\x06\x63onfig\x1aM\n\nMasterNode\x12?\n\tresources\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Resources\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\xd9\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12:\n\x04type\x18\x04 \x01(\x0e\x32,.yandex.cloud.mdb.elasticsearch.v1.Host.Type\x12?\n\tresources\x18\x05 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Resources\x12>\n\x06health\x18\x06 \x01(\x0e\x32..yandex.cloud.mdb.elasticsearch.v1.Host.Health\x12<\n\x08services\x18\x07 \x03(\x0b\x32*.yandex.cloud.mdb.elasticsearch.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\"<\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDATA_NODE\x10\x01\x12\x0f\n\x0bMASTER_NODE\x10\x02\"8\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xe8\x01\n\x07Service\x12=\n\x04type\x18\x01 \x01(\x0e\x32/.yandex.cloud.mdb.elasticsearch.v1.Service.Type\x12\x41\n\x06health\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.mdb.elasticsearch.v1.Service.Health\"/\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rELASTICSEARCH\x10\x01\"*\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x42|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=235
  _globals['_CLUSTER']._serialized_end=1355
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1047
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1092
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1094
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1167
  _globals['_CLUSTER_HEALTH']._serialized_start=1169
  _globals['_CLUSTER_HEALTH']._serialized_end=1232
  _globals['_CLUSTER_STATUS']._serialized_start=1234
  _globals['_CLUSTER_STATUS']._serialized_end=1355
  _globals['_MONITORING']._serialized_start=1357
  _globals['_MONITORING']._serialized_end=1418
  _globals['_CLUSTERCONFIG']._serialized_start=1420
  _globals['_CLUSTERCONFIG']._serialized_end=1542
  _globals['_ELASTICSEARCH']._serialized_start=1545
  _globals['_ELASTICSEARCH']._serialized_end=2036
  _globals['_ELASTICSEARCH_DATANODE']._serialized_start=1740
  _globals['_ELASTICSEARCH_DATANODE']._serialized_end=1957
  _globals['_ELASTICSEARCH_MASTERNODE']._serialized_start=1959
  _globals['_ELASTICSEARCH_MASTERNODE']._serialized_end=2036
  _globals['_RESOURCES']._serialized_start=2038
  _globals['_RESOURCES']._serialized_end=2118
  _globals['_HOST']._serialized_start=2121
  _globals['_HOST']._serialized_end=2594
  _globals['_HOST_TYPE']._serialized_start=2476
  _globals['_HOST_TYPE']._serialized_end=2536
  _globals['_HOST_HEALTH']._serialized_start=2538
  _globals['_HOST_HEALTH']._serialized_end=2594
  _globals['_SERVICE']._serialized_start=2597
  _globals['_SERVICE']._serialized_end=2829
  _globals['_SERVICE_TYPE']._serialized_start=2738
  _globals['_SERVICE_TYPE']._serialized_end=2785
  _globals['_SERVICE_HEALTH']._serialized_start=2538
  _globals['_SERVICE_HEALTH']._serialized_end=2580
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RawAudio(google.protobuf.message.Message):
    """RAW Audio format spec (no container to infer type). Used in AudioFormat options."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AudioEncoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AudioEncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RawAudio._AudioEncoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUDIO_ENCODING_UNSPECIFIED: RawAudio._AudioEncoding.ValueType  # 0
        AUDIO_ENCODING_LINEAR16_PCM: RawAudio._AudioEncoding.ValueType  # 1
        """Audio bit depth 16-bit signed little-endian (Linear PCM)."""

    class AudioEncoding(_AudioEncoding, metaclass=_AudioEncodingEnumTypeWrapper): ...
    AUDIO_ENCODING_UNSPECIFIED: RawAudio.AudioEncoding.ValueType  # 0
    AUDIO_ENCODING_LINEAR16_PCM: RawAudio.AudioEncoding.ValueType  # 1
    """Audio bit depth 16-bit signed little-endian (Linear PCM)."""

    AUDIO_ENCODING_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_HERTZ_FIELD_NUMBER: builtins.int
    AUDIO_CHANNEL_COUNT_FIELD_NUMBER: builtins.int
    audio_encoding: global___RawAudio.AudioEncoding.ValueType
    """ Type of audio encoding"""
    sample_rate_hertz: builtins.int
    """ PCM sample rate"""
    audio_channel_count: builtins.int
    """ PCM channel count."""
    def __init__(
        self,
        *,
        audio_encoding: global___RawAudio.AudioEncoding.ValueType = ...,
        sample_rate_hertz: builtins.int = ...,
        audio_channel_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audio_channel_count", b"audio_channel_count", "audio_encoding", b"audio_encoding", "sample_rate_hertz", b"sample_rate_hertz"]) -> None: ...

global___RawAudio = RawAudio

@typing.final
class ContainerAudio(google.protobuf.message.Message):
    """Audio with fixed type in container. Used in AudioFormat options."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ContainerAudioType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ContainerAudioTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContainerAudio._ContainerAudioType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONTAINER_AUDIO_TYPE_UNSPECIFIED: ContainerAudio._ContainerAudioType.ValueType  # 0
        CONTAINER_AUDIO_TYPE_WAV: ContainerAudio._ContainerAudioType.ValueType  # 1
        """Audio bit depth 16-bit signed little-endian (Linear PCM)."""
        CONTAINER_AUDIO_TYPE_OGG_OPUS: ContainerAudio._ContainerAudioType.ValueType  # 2
        """Data is encoded using the OPUS audio codec and compressed using the OGG container format."""
        CONTAINER_AUDIO_TYPE_MP3: ContainerAudio._ContainerAudioType.ValueType  # 3
        """Data is encoded using MPEG-1/2 Layer III and compressed using the MP3 container format."""

    class ContainerAudioType(_ContainerAudioType, metaclass=_ContainerAudioTypeEnumTypeWrapper): ...
    CONTAINER_AUDIO_TYPE_UNSPECIFIED: ContainerAudio.ContainerAudioType.ValueType  # 0
    CONTAINER_AUDIO_TYPE_WAV: ContainerAudio.ContainerAudioType.ValueType  # 1
    """Audio bit depth 16-bit signed little-endian (Linear PCM)."""
    CONTAINER_AUDIO_TYPE_OGG_OPUS: ContainerAudio.ContainerAudioType.ValueType  # 2
    """Data is encoded using the OPUS audio codec and compressed using the OGG container format."""
    CONTAINER_AUDIO_TYPE_MP3: ContainerAudio.ContainerAudioType.ValueType  # 3
    """Data is encoded using MPEG-1/2 Layer III and compressed using the MP3 container format."""

    CONTAINER_AUDIO_TYPE_FIELD_NUMBER: builtins.int
    container_audio_type: global___ContainerAudio.ContainerAudioType.ValueType
    """ Type of audio container."""
    def __init__(
        self,
        *,
        container_audio_type: global___ContainerAudio.ContainerAudioType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_audio_type", b"container_audio_type"]) -> None: ...

global___ContainerAudio = ContainerAudio

@typing.final
class AudioMetadata(google.protobuf.message.Message):
    """Audio format options."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_AUDIO_FIELD_NUMBER: builtins.int
    CONTAINER_AUDIO_FIELD_NUMBER: builtins.int
    @property
    def raw_audio(self) -> global___RawAudio:
        """Audio without container."""

    @property
    def container_audio(self) -> global___ContainerAudio:
        """Audio is wrapped in container."""

    def __init__(
        self,
        *,
        raw_audio: global___RawAudio | None = ...,
        container_audio: global___ContainerAudio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["AudioFormat", b"AudioFormat", "container_audio", b"container_audio", "raw_audio", b"raw_audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["AudioFormat", b"AudioFormat", "container_audio", b"container_audio", "raw_audio", b"raw_audio"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["AudioFormat", b"AudioFormat"]) -> typing.Literal["raw_audio", "container_audio"] | None: ...

global___AudioMetadata = AudioMetadata

@typing.final
class AudioChunk(google.protobuf.message.Message):
    """Data chunk with audio."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    """Bytes with audio data."""
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data"]) -> None: ...

global___AudioChunk = AudioChunk

@typing.final
class AudioStreamingRequest(google.protobuf.message.Message):
    """Streaming audio request
    First message should be audio metadata.
    The next messages are audio data chunks.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_METADATA_FIELD_NUMBER: builtins.int
    CHUNK_FIELD_NUMBER: builtins.int
    @property
    def audio_metadata(self) -> global___AudioMetadata:
        """Session options. Should be the first message from user."""

    @property
    def chunk(self) -> global___AudioChunk:
        """Chunk with audio data."""

    def __init__(
        self,
        *,
        audio_metadata: global___AudioMetadata | None = ...,
        chunk: global___AudioChunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["AudioEvent", b"AudioEvent", "audio_metadata", b"audio_metadata", "chunk", b"chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["AudioEvent", b"AudioEvent", "audio_metadata", b"audio_metadata", "chunk", b"chunk"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["AudioEvent", b"AudioEvent"]) -> typing.Literal["audio_metadata", "chunk"] | None: ...

global___AudioStreamingRequest = AudioStreamingRequest

@typing.final
class AudioRequest(google.protobuf.message.Message):
    """request for sending small audios (< 128 mb) in one go"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_METADATA_FIELD_NUMBER: builtins.int
    AUDIO_DATA_FIELD_NUMBER: builtins.int
    @property
    def audio_metadata(self) -> global___AudioMetadata:
        """audio metadata"""

    @property
    def audio_data(self) -> global___AudioChunk:
        """Bytes with audio data."""

    def __init__(
        self,
        *,
        audio_metadata: global___AudioMetadata | None = ...,
        audio_data: global___AudioChunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_data", b"audio_data", "audio_metadata", b"audio_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_data", b"audio_data", "audio_metadata", b"audio_metadata"]) -> None: ...

global___AudioRequest = AudioRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/transcription.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/transcription.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.speechsense.v1.analysis import utterance_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_utterance__statistics__pb2
from yandex.cloud.speechsense.v1.analysis import predefined_classifiers_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_predefined__classifiers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/speechsense/v1/analysis/transcription.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a\x1fgoogle/protobuf/timestamp.proto\x1a?yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto\x1a\x41yandex/cloud/speechsense/v1/analysis/predefined_classifiers.proto\"\xa4\x01\n\rTranscription\x12=\n\x07phrases\x18\x01 \x03(\x0b\x32,.yandex.cloud.speechsense.v1.analysis.Phrase\x12T\n\x13\x61lgorithms_metadata\x18\x02 \x03(\x0b\x32\x37.yandex.cloud.speechsense.v1.analysis.AlgorithmMetadata\"\xb2\x02\n\x06Phrase\x12\x16\n\x0e\x63hannel_number\x18\x01 \x01(\x03\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\x12@\n\x06phrase\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.speechsense.v1.analysis.PhraseText\x12J\n\nstatistics\x18\x05 \x01(\x0b\x32\x36.yandex.cloud.speechsense.v1.analysis.PhraseStatistics\x12V\n\x0b\x63lassifiers\x18\x06 \x03(\x0b\x32\x41.yandex.cloud.speechsense.v1.analysis.RecognitionClassifierResult\"\x80\x01\n\nPhraseText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x17\n\x0fnormalized_text\x18\x03 \x01(\t\x12\x39\n\x05words\x18\x04 \x03(\x0b\x32*.yandex.cloud.speechsense.v1.analysis.Word\"@\n\x04Word\x12\x0c\n\x04word\x18\x01 \x01(\t\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\"\xdf\x01\n\x11\x41lgorithmMetadata\x12\x35\n\x11\x63reated_task_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x63ompleted_task_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x05\x65rror\x18\x03 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.analysis.Error\x12\x10\n\x08trace_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"a\n\x10PhraseStatistics\x12M\n\nstatistics\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.speechsense.v1.analysis.UtteranceStatisticsB\x94\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x12TranscriptionProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.transcription_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\022TranscriptionProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_TRANSCRIPTION']._serialized_start=264
  _globals['_TRANSCRIPTION']._serialized_end=428
  _globals['_PHRASE']._serialized_start=431
  _globals['_PHRASE']._serialized_end=737
  _globals['_PHRASETEXT']._serialized_start=740
  _globals['_PHRASETEXT']._serialized_end=868
  _globals['_WORD']._serialized_start=870
  _globals['_WORD']._serialized_end=934
  _globals['_ALGORITHMMETADATA']._serialized_start=937
  _globals['_ALGORITHMMETADATA']._serialized_end=1160
  _globals['_ERROR']._serialized_start=1162
  _globals['_ERROR']._serialized_end=1200
  _globals['_PHRASESTATISTICS']._serialized_start=1202
  _globals['_PHRASESTATISTICS']._serialized_end=1299
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of the connection to get."""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___GetConnectionRequest = GetConnectionRequest

@typing.final
class SendToConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DataType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DataTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SendToConnectionRequest._DataType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DATA_TYPE_UNSPECIFIED: SendToConnectionRequest._DataType.ValueType  # 0
        BINARY: SendToConnectionRequest._DataType.ValueType  # 1
        """Binary data."""
        TEXT: SendToConnectionRequest._DataType.ValueType  # 2
        """Text data."""

    class DataType(_DataType, metaclass=_DataTypeEnumTypeWrapper): ...
    DATA_TYPE_UNSPECIFIED: SendToConnectionRequest.DataType.ValueType  # 0
    BINARY: SendToConnectionRequest.DataType.ValueType  # 1
    """Binary data."""
    TEXT: SendToConnectionRequest.DataType.ValueType  # 2
    """Text data."""

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of the connection to which send."""
    data: builtins.bytes
    """Data to send."""
    type: global___SendToConnectionRequest.DataType.ValueType
    """Type of the sending data."""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        data: builtins.bytes = ...,
        type: global___SendToConnectionRequest.DataType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "data", b"data", "type", b"type"]) -> None: ...

global___SendToConnectionRequest = SendToConnectionRequest

@typing.final
class SendToConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendToConnectionResponse = SendToConnectionResponse

@typing.final
class DisconnectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of the connection to disconnect."""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___DisconnectRequest = DisconnectRequest

@typing.final
class DisconnectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DisconnectResponse = DisconnectResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.playlist_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___GetPlaylistRequest = GetPlaylistRequest

@typing.final
class ListPlaylistsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "<field> <order>" (e.g. "createdAt desc").
    Default: "id asc".
    Possible fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    If value contains spaces or quotes,
    it should be in quotes (`'` or `"`) with the inner quotes being backslash escaped.
    Example: "key1='value' AND key2='value'".
    Supported operators: ["AND", "OR"].
    Supported fields: ["id", "title"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPlaylistsRequest = ListPlaylistsRequest

@typing.final
class ListPlaylistsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLISTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def playlists(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.Playlist]:
        """List of playlists for specific channel."""

    def __init__(
        self,
        *,
        playlists: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.Playlist] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "playlists", b"playlists"]) -> None: ...

global___ListPlaylistsResponse = ListPlaylistsResponse

@typing.final
class CreatePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Playlist title."""
    description: builtins.str
    """Playlist description."""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.PlaylistItem]:
        """List of playlist items."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        items: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.PlaylistItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "description", b"description", "items", b"items", "title", b"title"]) -> None: ...

global___CreatePlaylistRequest = CreatePlaylistRequest

@typing.final
class CreatePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___CreatePlaylistMetadata = CreatePlaylistMetadata

@typing.final
class UpdatePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    title: builtins.str
    """Playlist title."""
    description: builtins.str
    """Playlist description."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the playlist are going to be updated."""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.PlaylistItem]:
        """List of playlist items."""

    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        items: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.PlaylistItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "field_mask", b"field_mask", "items", b"items", "playlist_id", b"playlist_id", "title", b"title"]) -> None: ...

global___UpdatePlaylistRequest = UpdatePlaylistRequest

@typing.final
class UpdatePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___UpdatePlaylistMetadata = UpdatePlaylistMetadata

@typing.final
class DeletePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___DeletePlaylistRequest = DeletePlaylistRequest

@typing.final
class DeletePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___DeletePlaylistMetadata = DeletePlaylistMetadata

@typing.final
class BatchDeletePlaylistsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PLAYLIST_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def playlist_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of playlist IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        playlist_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "playlist_ids", b"playlist_ids"]) -> None: ...

global___BatchDeletePlaylistsRequest = BatchDeletePlaylistsRequest

@typing.final
class BatchDeletePlaylistsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_IDS_FIELD_NUMBER: builtins.int
    @property
    def playlist_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of playlist IDs."""

    def __init__(
        self,
        *,
        playlist_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_ids", b"playlist_ids"]) -> None: ...

global___BatchDeletePlaylistsMetadata = BatchDeletePlaylistsMetadata

@typing.final
class GetPlaylistPlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist."""
    @property
    def params(self) -> global___PlaylistPlayerParams: ...
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
        params: global___PlaylistPlayerParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["params", b"params", "playlist_id", b"playlist_id"]) -> None: ...

global___GetPlaylistPlayerURLRequest = GetPlaylistPlayerURLRequest

@typing.final
class PlaylistPlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, a player will be muted by default."""
    autoplay: builtins.bool
    """If true, playback will start automatically."""
    hidden: builtins.bool
    """If true, a player interface will be hidden by default."""
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___PlaylistPlayerParams = PlaylistPlayerParams

@typing.final
class GetPlaylistPlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct link to the playlist."""
    html: builtins.str
    """HTML embed code in Iframe format."""
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetPlaylistPlayerURLResponse = GetPlaylistPlayerURLResponse
